@@ -203,6 +203,13 @@ def extract_by_var(vars, state_codes,
     export_tmp_fp = path + '/us_census_api_extract.parquet.gzip'
     export_tmp_state_fp = path + '/us_census_api_extract_state.parquet.gzip'
 
+    # Special Case: These vars will eventually become column names.  In some datastores, the
+    # column name will need to be sanitized where camel case will turn into snake case.  
+    # eg. 'S0101_C01_002E' will turn into 's0101_c01_002_e'.  The additional underscore at the
+    # end fo the string may cause issues later on in a data pipeline.
+    vars = [x.lower() for x in vars]
+    
+    
     # Split df into batches smaller than 45 (50 - 5) to satisfy API Query limits
     vars = np.array_split(vars, math.ceil(len(vars)/45))
 
